from django.shortcuts import render, get_object_or_404
from util_demian import utils
from _data import contents
from .models import Portfolio


import logging
logger = logging.getLogger(__name__)
formatter = logging.Formatter('%(levelname)s: [%(name)s] %(message)s')
ch = logging.StreamHandler()
ch.setFormatter(formatter)
logger.addHandler(ch)
logger.setLevel(logging.ERROR)

font_link = "https://fonts.googleapis.com/css?" \
            "family=Open+Sans:wght@300,300i,400,400i,600,600i,700,700i&" \
            "family=Hahmlet:wght@100;200;300;400;500;600;700;800;900&" \
            "family=Noto+Sans+KR:wght@100;300;400;500;700;900&" \
            "family=Noto+Serif+KR:wght@200;300;400;500;600;700;900&" \
            "family=Raleway:wght@300,300i,400,400i,500,500i,600,600i,700,700i&" \
            "family=Poppins:wght@300,300i,400,400i,500,500i,600,600i,700,700i&display=swap"

def robots(request):
    from django.shortcuts import HttpResponse
    file_content = utils.make_robots()
    return HttpResponse(file_content, content_type="text/plain")


def home(request):
    """
        컨텍스트를 이곳에서 만들지 않고 _data 폴더의 contents.py에서 만들어진 것을 가져다 쓴다.
        """
    c = contents.context

    # _variables.scss에서 한글 폰트를 추가해주고 여기에 적절한 폰트 링크를 적용한다.
    c['font_link'] = font_link

    logger.info(c)
    return render(request, 'iportfolio/index.html', c)

def details(request, id: int):
    c = contents.context
    c.update({'obj': get_object_or_404(Portfolio, pk=id)})
    logger.debug(c)
    return render(request, "iportfolio/_portfolio-details.html", c)


from django.db import models


class Portfolio(models.Model):
    title = models.CharField('제목', max_length=20)
    subtitle = models.CharField('부제목', max_length=40)
    filter = models.ForeignKey(
        'Category',
        related_name='category',
        on_delete=models.PROTECT,
    )
    description = models.TextField('세부 설명', null=True, blank=True)
    image1 = models.ImageField(upload_to=f'images/portfolio/', null=True,
                               help_text="각 이미지 비율이(3x5, 4x5) 동일한 것이 보기 좋습니다.")
    image2 = models.ImageField(upload_to=f'images/portfolio/', null=True, blank=True)
    image3 = models.ImageField(upload_to=f'images/portfolio/', null=True, blank=True)
    image4 = models.ImageField(upload_to=f'images/portfolio/', null=True, blank=True)
    image5 = models.ImageField(upload_to=f'images/portfolio/', null=True, blank=True)
    url = models.URLField('참고링크', blank=True, null=True, help_text="공란 가능")

    def __str__(self):
        return self.title


class Category(models.Model):
    filter = models.CharField('카테고리', max_length=20)

    def __str__(self):
        return self.filter


from django.template import Library, loader
from ..models import Portfolio, Category

import logging
logger = logging.getLogger(__name__)
formatter = logging.Formatter('%(levelname)s: [%(name)s] %(message)s')
ch = logging.StreamHandler()
ch.setFormatter(formatter)
logger.addHandler(ch)
logger.setLevel(logging.ERROR)


register = Library()

# https://localcoder.org/django-inclusion-tag-with-configurable-template


@register.simple_tag(takes_context=True)
def about(context):
    t = loader.get_template("iportfolio/_about.html")
    context.update({

    })
    logger.info(context)
    return t.render(context.flatten())


@register.simple_tag(takes_context=True)
def hero(context):
    t = loader.get_template("iportfolio/_hero.html")
    context.update({

    })
    logger.info(context)
    return t.render(context.flatten())


@register.simple_tag(takes_context=True)
def testimonials(context):
    t = loader.get_template("iportfolio/_testimonials.html")
    context.update({

    })
    logger.info(context)
    return t.render(context.flatten())


@register.simple_tag(takes_context=True)
def facts(context):
    t = loader.get_template("iportfolio/_facts.html")
    context.update({

    })
    logger.info(context)
    return t.render(context.flatten())


@register.simple_tag(takes_context=True)
def contact(context):
    t = loader.get_template("iportfolio/_contact.html")
    context.update({

    })
    logger.info(context)
    return t.render(context.flatten())


@register.simple_tag(takes_context=True)
def services(context):
    t = loader.get_template("iportfolio/_services.html")
    context.update({

    })
    logger.info(context)
    return t.render(context.flatten())


@register.simple_tag(takes_context=True)
def skills(context):
    t = loader.get_template("iportfolio/_skills.html")
    context.update({

    })
    logger.info(context)
    return t.render(context.flatten())


@register.simple_tag(takes_context=True)
def resume(context):
    t = loader.get_template("iportfolio/_resume.html")
    context.update({

    })
    logger.info(context)
    return t.render(context.flatten())


@register.simple_tag(takes_context=True)
def portfolio(context):
    t = loader.get_template("iportfolio/_portfolio.html")
    context.update({
        'categories': Category.objects,
        'items': Portfolio.objects
    })
    logger.info(context)
    return t.render(context.flatten())
